@@ -57,6 +57,7 @@ sub read_option {
   if ( $opt{f} ) {
     my $tf = decode( locale => $opt{f} );
     my ( $tw, $tb, $suffix ) = $tf =~ m#([^\/\\]+)-([^\/\\]+)\.([^.]+)$#;
+    $opt_out{site} = lc($suffix);
     $opt_out{writer} = $tw unless ( defined $opt_out{writer} );
     $opt_out{book}   = $tb unless ( defined $opt_out{book} );
   }
@@ -76,5 +77,7 @@ if ( $opt{f} ) {
   } else {
     $xs->get_item( $opt{u}, %opt_out );
   }
+} elsif ($opt{s} and $opt{w} and $opt{b}){
+    $xs->get_item( "$opt{w}:$opt{b}", %opt_out );
 }
 
